# Copyright (c) 2022 CESNET
# 
# This software is released under the MIT License.
# https://opensource.org/licenses/MIT
from flask import Blueprint

def create_blueprint(app):
    """Blueprint for the routes and resources provided by NR-common-metadata."""
    return Blueprint(
        "invenio_app_rdm",
        __name__,
        template_folder="templates",
        static_folder="static",
    )



# Copyright (c) 2022 CESNET
# 
# This software is released under the MIT License.
# https://opensource.org/licenses/MIT

class NRCommonMetadataExt:
    """NR Common metadata extension."""

    def __init__(self, app, db=None):
        """
        Create an instance of the extension.
        :param app      the application
        :param db       database, not used
        """
        self.init_app(app, db=None)

    def init_app(self, app, db=None):
        """
        Initialize the extension.
        :param app      the application
        :param db       database, not used
        """



# Copyright (c) 2022 CESNET
# 
# This software is released under the MIT License.
# https://opensource.org/licenses/MIT

from .ext import NRCommonMetadataExt

__version__ = '4.0.0.dev15'

__all__ = ('__version__', 'NRCommonMetadataExt')
